@@ -114,6 +114,7 @@ const OverviewToolbar = new Lang.Class({
         this._viewSettingsId = 0;
         this._activeCollection = null;
         this._infoUpdatedId = 0;
+        this._countChangedId = 0;
 
         this.parent();
 
@@ -151,6 +152,7 @@ const OverviewToolbar = new Lang.Class({
         builder.add_from_resource('/org/gnome/Documents/ui/view-menu.ui');
         let viewMenu = builder.get_object('viewMenu');
 
+        // Translators: this is the menu to change view settings
         this._viewMenuButton = new Gtk.MenuButton({ tooltip_text: _("View Menu"),
                                                     popover: viewMenu });
         this.toolbar.pack_end(this._viewMenuButton);
@@ -286,6 +288,11 @@ const OverviewToolbar = new Lang.Class({
         this._viewMenuButton = null;
         this.toolbar.set_custom_title(null);
 
+        if (this._countChangedId != 0) {
+            Application.offsetDocumentsController.disconnect(this._countChangedId);
+            this._countChangedId = 0;
+        }
+
         if (this._collectionId != 0) {
             Application.documentManager.disconnect(this._collectionId);
             this._collectionId = 0;
@@ -323,6 +330,14 @@ const OverviewToolbar = new Lang.Class({
         this._setToolbarTitle();
         this.toolbar.show_all();
 
+        this._countChangedId = Application.offsetDocumentsController.connect('item-count-changed', Lang.bind(this,
+            function(controller, count) {
+                this.toolbar.foreach(Lang.bind(this,
+                    function(child) {
+                        child.set_sensitive(count != 0);
+                    }));
+            }));
+
         if (Application.searchController.getString() != '')
             Application.application.change_action_state('search', GLib.Variant.new('b', true));
     },
