@@ -43,6 +43,7 @@ const Utils = imports.utils;
 const View = imports.view;
 const WindowMode = imports.windowMode;
 const Presentation = imports.presentation;
+const Documents = imports.documents;
 
 const _FULLSCREEN_TOOLBAR_TIMEOUT = 2; // seconds
 
@@ -100,6 +101,8 @@ const PreviewView = new Lang.Class({
         this._zoomIn = Application.application.lookup_action('zoom-in');
         let zoomInId = this._zoomIn.connect('activate', Lang.bind(this,
             function() {
+                if (!this._model)
+                    return;
                 this._model.set_sizing_mode(EvView.SizingMode.FREE);
                 this.view.zoom_in();
             }));
@@ -107,6 +110,8 @@ const PreviewView = new Lang.Class({
         this._zoomOut = Application.application.lookup_action('zoom-out');
         let zoomOutId = this._zoomOut.connect('activate', Lang.bind(this,
             function() {
+                if (!this._model)
+                    return;
                 this._model.set_sizing_mode(EvView.SizingMode.FREE);
                 this.view.zoom_out();
             }));
@@ -168,13 +173,17 @@ const PreviewView = new Lang.Class({
             }));
     },
 
-    _onLoadStarted: function() {
+    _onLoadStarted: function(manager, doc) {
+        if (doc.viewType != Documents.ViewType.EV)
+            return;
         this._bookmarkPage.enabled = false;
         this._places.enabled = false;
         this._copy.enabled = false;
     },
 
     _onLoadError: function(manager, doc, message, exception) {
+        if (doc.viewType != Documents.ViewType.EV)
+            return;
         this._controlsVisible = true;
         this._syncControlsVisible();
         this._setError(message, exception.message);
@@ -569,9 +578,11 @@ const PreviewView = new Lang.Class({
 
             this.set_visible_child_full('view', Gtk.StackTransitionType.NONE);
         } else {
-            if (!this._jobFind.is_finished())
-                this._jobFind.cancel();
-            this._jobFind = null;
+	    if (this._jobFind) {
+	        if (!this._jobFind.is_finished())
+	            this._jobFind.cancel();
+	        this._jobFind = null;
+	    }
         }
     },
 
