@@ -206,7 +206,8 @@ const OverviewSearchbar = new Lang.Class({
 
         // create the dropdown button
         this._dropdownButton = new Gtk.ToggleButton(
-            { child: new Gtk.Arrow({ arrow_type: Gtk.ArrowType.DOWN }) });
+            { child: new Gtk.Image({ icon_name: 'go-down-symbolic',
+                                     icon_size: Gtk.IconSize.MENU }) });
         this._dropdownButton.get_style_context().add_class('raised');
         this._dropdownButton.get_style_context().add_class('image-button');
         this._dropdownButton.connect('toggled', Lang.bind(this,
