@@ -158,9 +158,7 @@ const CreateCollectionIconJob = new Lang.Class({
 
         if (icon instanceof Gio.ThemedIcon) {
             let theme = Gtk.IconTheme.get_default();
-            let flags =
-                Gtk.IconLookupFlags.FORCE_SIZE |
-                Gtk.IconLookupFlags.GENERIC_FALLBACK;
+            let flags = Gtk.IconLookupFlags.FORCE_SIZE;
             let info =
                 theme.lookup_by_gicon(icon, _SHELL_SEARCH_ICON_SIZE,
                                       flags);
@@ -317,7 +315,8 @@ const FetchIdsJob = new Lang.Class({
         this._cancellable = cancellable;
         searchController.setString(this._terms.join(' '));
 
-        let query = queryBuilder.buildGlobalQuery(Query.QueryFlags.SEARCH, null);
+        let sortBy = Application.settings.get_enum('sort-by');
+        let query = queryBuilder.buildGlobalQuery(Query.QueryFlags.SEARCH, null, sortBy);
         Application.connectionQueue.add(query.sparql, this._cancellable, Lang.bind(this,
             function(object, res) {
                 let cursor = null;
